@@ -1,19 +1,26 @@
 #' Saving and loading a model specification, SA and pre-adjustment in X13 and TRAMO-SEATS
 #' @description
-#' \code{save_spec} saves a SA or RegARIMA model specification. \code{load_spec} loads the previously saved model specification.
+#' \code{save_spec} saves a SA or RegARIMA model specification.
+#' \code{load_spec} loads the previously saved model specification.
 #'
-#' @param object object of one of the classes: \code{c("SA_spec","X13")}, \code{c("SA_spec","TRAMO_SEATS")}, \code{c("SA","X13")}, \code{c("SA","TRAMO_SEATS")}, \code{c("regarima_spec","X13")}, \code{c("regarima_spec","TRAMO_SEATS")}, \code{c("regarima","X13")}, \code{c("regarima","TRAMO_SEATS")}.
-#' @param file (path and) name of the file where the model specification will be saved (have been saved).
+#' @param object an object of one of the following classes: \code{c("SA_spec","X13")},
+#' \code{c("SA_spec","TRAMO_SEATS")}, \code{c("SA","X13")}, \code{c("SA","TRAMO_SEATS")},
+#' \code{c("regarima_spec","X13")}, \code{c("regarima_spec","TRAMO_SEATS")}, \code{c("regarima","X13")},
+#' \code{c("regarima","TRAMO_SEATS")}.
+#' @param file the (path and) name of the file where the model specification will be/has been saved.
 #'
 #' @details
-#' \code{save_spec} saves the final model specification of a \code{"SA_spec"}, \code{"SA"}, \code{"regarima_spec"} or \code{"regarima"} class object.
-#' \code{load_spec} loads the previously saved model specification. It creates a \code{c("SA_spec","X13")}, \code{c("sA_spec","TRAMO_SEATS")}, \code{c("regarima_spec","X13")} or \code{c("regarima_spec","TRAMO_SEATS")} class object, in line with the class of the previously saved model specification.
+#' \code{save_spec} saves the final model specification of a \code{"SA_spec"}, \code{"SA"},
+#' \code{"regarima_spec"} or \code{"regarima"} class object.
+#' \code{load_spec} loads the previously saved model specification. It creates a \code{c("SA_spec","X13")},
+#' \code{c("sA_spec","TRAMO_SEATS")}, \code{c("regarima_spec","X13")} or \code{c("regarima_spec","TRAMO_SEATS")}
+#' class object, in line with the class of the previously saved model specification.
 #'
 #' @return
-#' \code{load_spec}  returns an object of class \code{"SA_spec"} or \code{"regarima_spec"}.
+#' \code{load_spec} returns an object of class \code{"SA_spec"} or \code{"regarima_spec"}.
 
 #' @references
-#' Info on JDemtra+, usage and functions:
+#' Info on JDemetra+, usage and functions:
 #' \url{https://ec.europa.eu/eurostat/cros/content/documentation_en}
 #'
 #' @examples
@@ -38,24 +45,24 @@
 #'
 #' dir <- tempdir()
 #'
-#'  # Save the model specification from a c("regarima_spec","X13") class object
+#'  # To save the model specification of a c("regarima_spec","X13") class object
 #' save_spec(myspec2, file.path(dir, "specx13.RData"))
-#'  # Save the model specification from a c("regarima","X13") class object
+#'  # To save the model specification of a c("regarima","X13") class object
 #' save_spec(myreg2, file.path(dir,"regx13.RData"))
-#'  # Save the model specification from a c("regarima_spec","TRAMO_SEATS") class object
+#'  # To save the model specification of a c("regarima_spec","TRAMO_SEATS") class object
 #' save_spec(myspec4, file.path(dir,"specTS.RData"))
-#'  # Save the model specification from a c("regarima","TRAMO_SEATS") class object
+#'  # To save the model specification of a c("regarima","TRAMO_SEATS") class object
 #' save_spec(myreg4, file.path(dir,"regTS.RData"))
-#'  # Save model from a c("SA_spec","X13") class object
+#'  # To save the model of a c("SA_spec","X13") class object
 #' save_spec(myspec6, file.path(dir,"specFullx13.RData"))
-#'  # Save model from a c("SA","X13") class object
+#'  # To save the model of a c("SA","X13") class object
 #' save_spec(mysa6, file.path(dir,"sax13.RData"))
-#'  # Save model from a c("SA_spec","TRAMO_SEATS") class object
+#'  # To save the model of a c("SA_spec","TRAMO_SEATS") class object
 #' save_spec(myspec7, file.path(dir,"specFullTS.RData"))
-#'  # Save model from a c("SA","TRAMO_SEATS") class object
+#'  # To save the model of a c("SA","TRAMO_SEATS") class object
 #' save_spec(mysa7, file.path(dir,"saTS.RData"))
 #'
-#'  # Load the model specification
+#'  # To load a model specification:
 #' myspec2a <- load_spec(file.path(dir,"specx13.RData"))
 #' myspec2b <- load_spec(file.path(dir,"regx13.RData"))
 #' myspec4a <- load_spec(file.path(dir,"specTS.RData"))
@@ -65,7 +72,7 @@
 #' myspec7a <- load_spec(file.path(dir,"specFullTS.RData"))
 #' myspec7b <- load_spec(file.path(dir,"saTS.RData"))
 #'
-#'
+#' # To use the re-loaded specifications and models:
 #' regarima(myseries, myspec2a)
 #' x13(myseries, myspec6a)
 #' tramoseats(myseries, myspec7a)
@@ -74,10 +81,12 @@
 #' x13(myseries, myspec6b)
 #' tramoseats(myseries, myspec7b)
 #' }
+#' @rdname save_spec
+#' @name save_spec
 #' @export
 save_spec = function (object, file = file.path(tempdir(), "spec.RData")) {
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("The function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   estimate <- s_estimate(object)
   transform <- s_transform(object)
@@ -113,14 +122,14 @@ save_spec = function (object, file = file.path(tempdir(), "spec.RData")) {
   class(spec) <- cspec
   save(spec, file = file)
 }
-# Generic function to load previously saved model specification
+# Generic function to load a previously saved model specification
 #' @rdname save_spec
 #' @name save_spec
 #' @export
 load_spec <- function (file = "spec.RData") {
   object <- get(load(file = file))
   if (inherits(object,c("SA_saveX13","SA_saveTS","regarima_saveX13","regarima_saveTS"))==FALSE)
-    stop("no model specification found in the file!\n")
+    stop("No model specification was found in the file!\n")
 
   s.estimate <- object$estimate
   s.transform <- object$transform
