@@ -1,18 +1,22 @@
-#' Access model specification, SA and pre-adjustment in X13 and TRAMO-SEATS
+#' Access a model specification, a SA or a pre-adjustment model in X13 and TRAMO-SEATS
 #' @description
-#' Below functions access different parts of the final model specification as included in the \code{"SA", "regarima", "SA_spec"} and \code{"regarima_spec"} S3 class objects.
-#' @param object object of one of the classes: \code{c("SA","X13")}, \code{c("SA","TRAMO_SEATS")}, \code{c("SA_spec","X13")}, \code{c("SA_spec","TRAMO_SEATS")}, \code{c("regarima","X13")}, \code{c("regarima","TRAMO_SEATS")}, \code{c("regarima_spec","X13")}, \code{c("regarima_spec","TRAMO_SEATS")}.
+#' The following functions enable the access to different parts of the final model specification,
+#' as included in the \code{"SA", "regarima", "SA_spec"} and \code{"regarima_spec"} S3 class objects.
+#' @param object an object of one of the following classes: \code{c("SA","X13")},
+#' \code{c("SA","TRAMO_SEATS")}, \code{c("SA_spec","X13")}, \code{c("SA_spec","TRAMO_SEATS")},
+#' \code{c("regarima","X13")}, \code{c("regarima","TRAMO_SEATS")}, \code{c("regarima_spec","X13")},
+#' \code{c("regarima_spec","TRAMO_SEATS")}.
 #' @name specification
 NULL
 #' @return
 #' \itemize{
 #' \item \code{s_estimate} returns a data.frame with the \emph{estimate} variables
-#' \item \code{s_transform} returns a data.frame with the \emph{transform} varaibles
+#' \item \code{s_transform} returns a data.frame with the \emph{transform} variables
 #' \item \code{s_usrdef} returns a data.frame with the \emph{user-defined regressors} (outliers and variables) model specification, indicating if those variables are included in the model and if coefficients are pre-specified
 #' \item \code{s_preOut} returns a data.frame with the \emph{pre-specified outliers}
-#' \item \code{s_preVar} returns a list with the information on the user-defined variables, including: \code{series} - the time series and \code{description} - data.frame with the variable type and coefficients
+#' \item \code{s_preVar} returns a list with information on the user-defined variables, including: \code{series} - the time series and \code{description} - data.frame with the variable type and coefficients
 #' \item \code{s_td} returns a data.frame with the \emph{trading.days} variables
-#' \item \code{s_easter} returns a data.frame with the \emph{easter} variables
+#' \item \code{s_easter} returns a data.frame with the \emph{easter} variable
 #' \item \code{s_out} returns a data.frame with the \emph{outliers} detection variables
 #' \item \code{s_arima} returns a data.frame with the \emph{arima} variables
 #' \item \code{s_arimaCoef} returns a data.frame with the user-specified ARMA coefficients
@@ -138,7 +142,7 @@ s_estimate <- function(object = NA){
 #' @export
 s_transform <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -169,7 +173,7 @@ s_transform <- function(object = NA){
 #' @export
 s_usrdef <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -200,7 +204,7 @@ s_usrdef <- function(object = NA){
 #' @export
 s_preOut <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -227,7 +231,7 @@ s_preOut <- function(object = NA){
 #' @export
 s_preVar <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -254,7 +258,7 @@ s_preVar <- function(object = NA){
 #' @export
 s_td <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -285,7 +289,7 @@ s_td <- function(object = NA){
 #' @export
 s_easter <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -316,7 +320,7 @@ s_easter <- function(object = NA){
 #' @export
 s_out <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -346,7 +350,7 @@ s_out <- function(object = NA){
 #' @export
 s_arima <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -377,7 +381,7 @@ s_arima <- function(object = NA){
 #' @export
 s_arimaCoef <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -403,7 +407,7 @@ s_arimaCoef <- function(object = NA){
 #' @export
 s_fcst <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -432,7 +436,7 @@ s_fcst <- function(object = NA){
 #' @export
 s_span <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
-    stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "X13") &&
       (
@@ -459,7 +463,7 @@ s_span <- function(object = NA){
 #' @export
 s_x11 <- function(object = NA){
   if (inherits(object, c("SA","SA_spec"))==FALSE)
-    stop("use only with \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "SA")){
     return(object$decomposition$specification)
@@ -474,7 +478,7 @@ s_x11 <- function(object = NA){
 #' @export
 s_seats <- function(object = NA){
   if (inherits(object, c("SA","SA_spec"))==FALSE)
-    stop("use only with \"SA\" and \"SA_spec\" objects", call. = FALSE)
+    stop("This function must only be used with \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
   if (inherits(object, "SA")){
     return(object$decomposition$specification)
